/*
   program : SheppLogan, SheppLogan2recon

   $Source: /home/yee/C/RCS/SheppLogan.h,v $
   $Author: yee $
   $Date: 1999/02/10 16:39:47 $
   $Revision: 1.2 $

   Contains the specifications for the SheppLogan head phantom

   Compile Options : none

   Runtime Parameters : none

   Assumptions : none known

   Bugs : none known

   To Do : nothing

   $Log: SheppLogan.h,v $
   Revision 1.2  1999/02/10 16:39:47  yee
   *** empty log message ***

   Revision 1.1  1999/02/05 03:54:32  yee
   Initial revision


   Copyright 1999 by Conway Yee.  All rights reserved.
 */
#ifndef SHEPPLOGAN_H
#define SHEPPLOGAN_H

#define MAX_SL 10  /* number of ellipses in Shepp-Logan head phantom */
#define DEG_SL  6  /* degrees of freedom in each ellipse */

              /* The extra column in each ellipse is for atan(ORIG_Y/ORIG_X) */
              /* and SQRT(X1^2+Y1^2) which are needed for each projection */
              /* The letters refer to the ellipse lettering on Kak&Slaney. */
              /* Fig 3.4b on p. 53. */
static double SL[MAX_SL][DEG_SL+2] = {    /* Shepp-Logan head phantom */
  {  0.0  ,  0.0    , 0.92  ,  0.69   ,  90.0 ,  2.0  , 0.0 , 0.0 }, /* a */ 
  {  0.0  , -0.0184 , 0.874 ,  0.6624 ,  90.0 , -0.98 , 0.0 , 0.0 }, /* b */
  {  0.22 ,  0.0    , 0.31  ,  0.11   ,  72.0 , -0.02 , 0.0 , 0.0 }, /* c */
  { -0.22 ,  0.0    , 0.41  ,  0.16   , 108.0 , -0.02 , 0.0 , 0.0 }, /* d */
  {  0.0  ,  0.35   , 0.25  ,  0.21   ,  90.0 ,  0.01 , 0.0 , 0.0 }, /* e */
  {  0.0  ,  0.1    , 0.046 ,  0.046  ,   0.0 ,  0.01 , 0.0 , 0.0 }, /* f */
  {  0.0  , -0.1    , 0.046 ,  0.046  ,   0.0 ,  0.01 , 0.0 , 0.0 }, /* g */
  { -0.08 , -0.605  , 0.046 ,  0.023  ,   0.0 ,  0.01 , 0.0 , 0.0 }, /* h */
  {  0.0  , -0.605  , 0.023 ,  0.023  ,   0.0 ,  0.01 , 0.0 , 0.0 }, /* i */
  {  0.06 , -0.605  , 0.046 ,  0.023  ,  90.0 ,  0.01 , 0.0 , 0.0 }  /* j */
};

enum ellipse {
        ORIG_X,   /* origin in X axis */
        ORIG_Y,   /* origin in Y axis */
        MAJOR,    /* major axis */
        MINOR,    /* minor axis */
        ROTATION_ANGLE, /* angle of rotation */
                        /* initially in degrees & converted to radians */
        INDEX,    /* refractive index */
        ATANYX,   /* atan(Y1/X1) Kak&Slaney p. 56 (eqn 6) */
        DIST_ORIG /* sqrt(X1^2+Y1^2) Kak&Slaney p. 56 (eqn 6) */
};

/* support definitions for the definitions of ellipses.  Notation from
   Kak & Slaney pgs. 53-6. */

#define A       SL[el][MAJOR]     /* major axis */
#define B       SL[el][MINOR]     /* minor axis */
#define RO      SL[el][INDEX]     /* index of refraction */
#define ALPHA   SL[el][ROTATION_ANGLE]  /* rotation angle */
#define X1      SL[el][ORIG_X]    /* x-axis center coordinate of ellipse */
#define Y1      SL[el][ORIG_Y]    /* y-axis center coordinate of ellipse */
#define ATAN_YX SL[el][ATANYX]    /* atan(Y1/X1) */
#define S       SL[el][DIST_ORIG] /* sqrt(X1^2+Y1^2) */

       /* convert angle to radians, atan(Y1/X1) & s Kak&Slaney p. 56 (eqn 6) */
#define SetupSL() {                      \
          {                              \
            int el; /* counter */        \
                                         \
            for(el=0;el<MAX_SL;el++) {   \
              ALPHA *= PI/180.0;         \
              ATAN_YX=atan2(Y1,X1);      \
              S = pow(X1*X1+Y1*Y1,0.5);  \
            }                            \
          }                              \
        }

#endif SHEPPLOGAN_H
